@@ -5,10 +5,12 @@ from pydantic import BaseModel
 from . import CRUDGenerator, NOT_FOUND
 
 try:
-    from databases.core import Database
     from sqlalchemy.sql.schema import Table
+    from databases.core import Database
 except ImportError:
     databases_installed = False
+    Table = None
+    Database = None
 else:
     databases_installed = True
 
