@@ -4,18 +4,21 @@ from pydantic import BaseModel
 
 from . import CRUDGenerator, NOT_FOUND
 
+
 try:
     from sqlalchemy.orm import Session
+    from sqlalchemy.ext.declarative import DeclarativeMeta
 except ImportError:
     sqlalchemy_installed = False
     Session = None
+    DeclarativeMeta = None
 else:
     sqlalchemy_installed = True
 
 
 class SQLAlchemyCRUDRouter(CRUDGenerator):
 
-    def __init__(self, schema: BaseModel, db_model: Session, db: ..., *args, **kwargs):
+    def __init__(self, schema: BaseModel, db_model: DeclarativeMeta, db: Session, *args, **kwargs):
         assert sqlalchemy_installed, "SQLAlchemy must be installed to use the SQLAlchemyCRUDRouter."
 
         self.db_model = db_model
